==> aTunes_1.12.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/actions/CheckUpdatesAction.java <==
/*
 * aTunes 1.12.0
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.actions;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.kernel.Kernel;
import net.sourceforge.atunes.kernel.handlers.UpdateHandler;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * Called to search for a new version of the application
 * 
 * @author fleax
 * 
 */
public class CheckUpdatesAction extends AbstractAction {

	/**
	 * 
	 */
	private static final long serialVersionUID = 999420226547524484L;

	CheckUpdatesAction() {
		super(LanguageTool.getString("CHECK_FOR_UPDATES"), ImageLoader.CHECK_FOR_UPDATES);
		putValue(SHORT_DESCRIPTION, LanguageTool.getString("CHECK_FOR_UPDATES"));
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		UpdateHandler.getInstance().checkUpdates(Kernel.getInstance().state.getProxy(), true, true);
	}

}

==> aTunes_1.13.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/actions/CheckUpdatesAction.java <==
/*
 * aTunes 1.13.0
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.actions;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.kernel.modules.state.ApplicationState;
import net.sourceforge.atunes.kernel.modules.updates.UpdateHandler;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * Called to search for a new version of the application
 * 
 * @author fleax
 * 
 */
public class CheckUpdatesAction extends AbstractAction {

    private static final long serialVersionUID = 999420226547524484L;

    CheckUpdatesAction() {
        super(LanguageTool.getString("CHECK_FOR_UPDATES"), ImageLoader.CHECK_FOR_UPDATES);
        putValue(SHORT_DESCRIPTION, LanguageTool.getString("CHECK_FOR_UPDATES"));
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        UpdateHandler.getInstance().checkUpdates(ApplicationState.getInstance().getProxy(), true, true);
    }

}
